# -*- coding: utf-8 -*-

#
# (c) Rene Hadler iteas IT Services GmbH
# support@iteas.at
# www.iteas.at
#

from __future__ import absolute_import

import subprocess
from univention.listener import ListenerModuleHandler, ListenerModuleConfiguration


# Bug #48886: udl-ctrl parses this name with sed
name = 'univention-radius-iteas'

# Template: https://github.com/univention/univention-corporate-server/blob/5.0-2/management/univention-directory-listener/examples/complex_handler.py

class AppListener(ListenerModuleHandler):
        run_update = False

        class Configuration(ListenerModuleConfiguration):
                name = 'univention-radius-iteas'
                description = 'Listener module for univention-radius-iteas'
                ldap_filter = '(&(objectClass=posixGroup)(objectClass=radiusprofile))'
                attributes = []

        def create(self, dn, new):
                if b'radiusprofile' in new.get('objectClass', []):
                        self.run_update = True
                        self.logger.info('config update triggered')

        def modify(self, dn, old, new, old_dn):
                # only update the file, if relevant
                if old_dn:
                        self.run_update = True
                        self.logger.info('config update triggered (move)')
                elif b'radiusprofile' in old.get('objectClass', []):
                        if (
                                set(old.get('radiusReplyAttribute', [])) != set(new.get('radiusReplyAttribute', [])) or
                                set(old.get('cn', [])) != set(new.get('cn', []))
                        ):
                                self.run_update = True
                                self.logger.info('config update triggered')

        def remove(self, dn, old):
                if b'radiusprofile' in old.get('objectClass', []):
                        self.run_update = True
                        self.logger.info('config update triggered')

        def post_run(self):
                if self.run_update:
                        self.run_update = False
                        with self.as_root():
                                self.logger.info('Updating ldap-groups-attrs.conf')
                                subprocess.call(['/usr/sbin/univention-radius-iteas-update-ldapgroups-conf'])
                                self.logger.info('Restarting freeradius')
                                subprocess.call(['systemctl', 'try-restart', 'freeradius'])
